@@ -1,3 +1,5 @@
+from functools import partial
+
 from telegram.ext import (
     CommandHandler,
     ConversationHandler,
@@ -10,17 +12,12 @@ from quiz_bots import settings
 from quiz_bots.bots_helpers import send_message_to_tg_chat
 from quiz_bots.quiz_helpers import get_clean_text_of_answer
 from quiz_bots.redis_utils import (
-    connect_to_redis,
     get_answer_to_last_question_of_user,
     get_last_asked_question_from_redis,
-    get_quiz_content_from_redis,
     get_random_question,
     save_last_asked_question_to_redis,
 )
 
-REDIS_CONNECTION = connect_to_redis()
-QUIZ_CONTENT = get_quiz_content_from_redis(REDIS_CONNECTION)
-
 BUTTON_NEW_QUESTION = 'Новый вопрос'
 BUTTON_GIVE_IN = 'Сдаться'
 BUTTON_SCORE = 'Мой счет'
@@ -43,9 +40,9 @@ def welcome_message(update, context):
     return CHOOSING
 
 
-def handle_new_question_request(update, context) -> int:
+def handle_new_question_request(redis_client, update, context) -> int:
     """Sends a random question to the user."""
-    question, number_of_question = get_random_question(QUIZ_CONTENT)
+    question = get_random_question(redis_client)
 
     if context.user_data.get('button_give_in_flag'):
         custom_keyboard = [
@@ -58,29 +55,29 @@ def handle_new_question_request(update, context) -> int:
         ]
     send_message_to_tg_chat(
         update,
-        question['question'].replace('\n', ' '),
+        question.replace('\n', ' '),
         custom_keyboard,
     )
 
     save_last_asked_question_to_redis(
+        question=question,
         user_id=update.message.from_user.id,
-        redis_connection=REDIS_CONNECTION,
+        redis_client=redis_client,
         social_network='tg',
-        number_of_question=number_of_question,
     )
 
     return WAIT_ANSWER
 
 
-def handle_solution_attempt(update, context):
+def handle_solution_attempt(redis_client, update, context):
     """Checks answer of user."""
     last_asked_question = get_last_asked_question_from_redis(
+        redis_client=redis_client,
         user_id=update.message.from_user.id,
-        redis_connection=REDIS_CONNECTION,
         social_network='tg',
     )
     answer_to_last_question_of_user = get_answer_to_last_question_of_user(
-        redis_connection=REDIS_CONNECTION,
+        redis_client=redis_client,
         last_asked_question=last_asked_question,
     )
     clean_answer = get_clean_text_of_answer(answer_to_last_question_of_user)
@@ -100,19 +97,19 @@ def handle_solution_attempt(update, context):
     return CHOOSING
 
 
-def handle_opportunity_to_give_in(update, context):
+def handle_opportunity_to_give_in(redis_client, update, context):
     """Handles clicking the "Give in" button.
 
     The bot sends the user an answer to the question
     and sends the next question with the next message.
     """
     last_asked_question = get_last_asked_question_from_redis(
+        redis_client=redis_client,
         user_id=update.message.from_user.id,
-        redis_connection=REDIS_CONNECTION,
         social_network='tg',
     )
     answer_to_last_question_of_user = get_answer_to_last_question_of_user(
-        redis_connection=REDIS_CONNECTION,
+        redis_client=redis_client,
         last_asked_question=last_asked_question,
     )
     send_message_to_tg_chat(
@@ -121,7 +118,7 @@ def handle_opportunity_to_give_in(update, context):
     )
     context.user_data['button_give_in_flag'] = True
 
-    handle_new_question_request(update, context)
+    handle_new_question_request(redis_client, update, context)
 
     return WAIT_ANSWER
 
@@ -150,7 +147,7 @@ def cancel(update, context):
     return ConversationHandler.END
 
 
-def start_tg_bot():
+def start_tg_bot(args, redis_client):
     """Launch the TG bot."""
     updater = Updater(settings.tg_token, use_context=True)
 
@@ -163,17 +160,17 @@ def start_tg_bot():
             CHOOSING: [
                 MessageHandler(
                     Filters.regex('^Новый вопрос$'),
-                    handle_new_question_request,
+                    partial(handle_new_question_request, redis_client),
                 ),
                 MessageHandler(
                     Filters.regex('^Сдаться$'),
-                    handle_opportunity_to_give_in,
+                    partial(handle_opportunity_to_give_in, redis_client),
                 ),
             ],
             WAIT_ANSWER: [
                 MessageHandler(
                     Filters.regex('^Сдаться$'),
-                    handle_opportunity_to_give_in,
+                    partial(handle_opportunity_to_give_in, redis_client),
                 ),
                 MessageHandler(
                     Filters.regex('^Вопрос составлен неверно$'),
@@ -181,7 +178,7 @@ def start_tg_bot():
                 ),
                 MessageHandler(
                     Filters.text,
-                    handle_solution_attempt,
+                    partial(handle_solution_attempt, redis_client),
                 ),
             ],
         },
