@@ -12,26 +12,21 @@ from quiz_bots.bots_helpers import (
 )
 from quiz_bots.quiz_helpers import get_clean_text_of_answer
 from quiz_bots.redis_utils import (
-    connect_to_redis,
     get_answer_to_last_question_of_user,
     get_last_asked_question_from_redis,
-    get_quiz_content_from_redis,
     get_random_question,
     save_last_asked_question_to_redis,
 )
 
-REDIS_CONNECTION = connect_to_redis()
-QUIZ_CONTENT = get_quiz_content_from_redis(REDIS_CONNECTION)
-
 BUTTON_NEW_QUESTION = BotKeyboardButton(text='Новый вопрос', color=VkKeyboardColor.PRIMARY)
 BUTTON_GIVE_IN = BotKeyboardButton(text='Сдаться', color=VkKeyboardColor.NEGATIVE)
 BUTTON_SCORE = BotKeyboardButton(text='Мой счет', color=VkKeyboardColor.POSITIVE)
 BUTTON_QUESTION_IS_MADE_INCORRECTLY = BotKeyboardButton(text='Вопрос составлен неверно', color=VkKeyboardColor.DEFAULT)
 
 
-def handle_new_question_request(vk, event, button_give_in_flag: float = False) -> None:
+def handle_new_question_request(vk, event, redis_client, button_give_in_flag: float = False) -> None:
     """Sends a random question to the user."""
-    question, number_of_question = get_random_question(QUIZ_CONTENT)
+    question = get_random_question(redis_client)
     user_id = event.user_id
 
     if button_give_in_flag:
@@ -48,27 +43,27 @@ def handle_new_question_request(vk, event, button_give_in_flag: float = False) -
             top_buttons=top_buttons,
             bottom_buttons=bottom_buttons,
         ),
-        message_text=question['question'].replace('\n', ' '),
+        message_text=question.replace('\n', ' '),
     )
 
     save_last_asked_question_to_redis(
+        question=question,
         user_id=user_id,
-        redis_connection=REDIS_CONNECTION,
+        redis_client=redis_client,
         social_network='vk',
-        number_of_question=number_of_question,
     )
 
 
-def handle_solution_attempt(vk, event) -> None:
+def handle_solution_attempt(vk, event, redis_client) -> None:
     """Checks answer of user."""
     user_id = event.user_id
     last_asked_question = get_last_asked_question_from_redis(
+        redis_client=redis_client,
         user_id=user_id,
-        redis_connection=REDIS_CONNECTION,
         social_network='vk',
     )
     answer_to_last_question_of_user = get_answer_to_last_question_of_user(
-        redis_connection=REDIS_CONNECTION,
+        redis_client=redis_client,
         last_asked_question=last_asked_question,
     )
     if event.text.lower() == get_clean_text_of_answer(answer_to_last_question_of_user):
@@ -89,7 +84,7 @@ def handle_solution_attempt(vk, event) -> None:
     )
 
 
-def handle_opportunity_to_give_in(vk, event) -> None:
+def handle_opportunity_to_give_in(vk, event, redis_client) -> None:
     """Handles clicking the "Surrender" button.
 
     The bot sends the user an answer to the question
@@ -97,12 +92,12 @@ def handle_opportunity_to_give_in(vk, event) -> None:
     """
     user_id = event.user_id
     last_asked_question = get_last_asked_question_from_redis(
+        redis_client=redis_client,
         user_id=user_id,
-        redis_connection=REDIS_CONNECTION,
         social_network='vk',
     )
     answer_to_last_question_of_user = get_answer_to_last_question_of_user(
-        redis_connection=REDIS_CONNECTION,
+        redis_client=redis_client,
         last_asked_question=last_asked_question,
     )
     send_message_to_vk_chat(
@@ -110,7 +105,7 @@ def handle_opportunity_to_give_in(vk, event) -> None:
         user_id=user_id,
         message_text=answer_to_last_question_of_user,
     )
-    handle_new_question_request(vk, event, button_give_in_flag=True)
+    handle_new_question_request(vk, event, redis_client, button_give_in_flag=True)
 
 
 def handler_question_is_incorrect(vk, event) -> None:
@@ -126,7 +121,7 @@ def handler_question_is_incorrect(vk, event) -> None:
     )
 
 
-def start_vk_bot():  # noqa: WPS210, WPS231
+def start_vk_bot(args, redis_client):  # noqa: WPS210, WPS231
     """Launch the VK bot."""
     vk_group_token = settings.vk_group_token
     vk_session = vk_api.VkApi(token=vk_group_token)
@@ -135,10 +130,10 @@ def start_vk_bot():  # noqa: WPS210, WPS231
     for event in longpoll.listen():
         if event.type == VkEventType.MESSAGE_NEW and event.to_me:
             if event.text == 'Новый вопрос':
-                handle_new_question_request(vk, event)
+                handle_new_question_request(vk, event, redis_client)
             elif event.text == 'Сдаться':
-                handle_opportunity_to_give_in(vk, event)
+                handle_opportunity_to_give_in(vk, event, redis_client)
             elif event.text == 'Вопрос составлен неверно':
                 handler_question_is_incorrect(vk, event)
             else:
-                handle_solution_attempt(vk, event)
+                handle_solution_attempt(vk, event, redis_client)
